@@ -14,7 +14,10 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity", "0.2.9", __name__[0:-6], "identity@0.2.9.jsii.tgz"
+    "@aws-prototyping-sdk/identity",
+    "0.2.11",
+    __name__[0:-6],
+    "identity@0.2.11.jsii.tgz",
 )
 
 __all__ = [
